@@ -1,6 +1,6 @@
 package Class::Generate;
 
-use 5.008;
+use 5.010;
 use strict;
 use Carp;
 use warnings::register;
@@ -13,7 +13,7 @@ BEGIN {
     require Exporter;
     @ISA = qw(Exporter);
     @EXPORT_OK = (qw(&class &subclass &delete_class), qw($save $accept_refs $strict $allow_redefine $class_var $instance_var $check_params $check_code $check_default $nfi $warnings));
-    $VERSION = '1.10';
+    $VERSION = '1.15';
 
     $accept_refs    = 1;
     $strict	    = 1;
@@ -117,14 +117,14 @@ sub subclass(%) {				# One of the three interface
 
 sub delete_class(@) {					# One of the three interface routines
     for my $class ( @_ ) {				# to the package.  Deletes a class
-	next if ! eval 'defined %' . $class . '::';	# declared using Class::Generate.
-	if ( ! eval 'defined %' . $class . '::_cginfo' ) {
+	next if ! eval '%' . $class . '::';		# declared using Class::Generate.
+	if ( ! eval '%' . $class . '::_cginfo' ) {
 	    croak $class, ': Class was not declared using ', __PACKAGE__;
 	}
 	delete_package($class);
 	Class::Generate::Class_Holder::remove($class);
 	my $code_checking_package = __PACKAGE__ . '::Code_Checker::check::' . $class . '::';
-	if ( eval 'defined %' . $code_checking_package ) {
+	if ( eval '%' . $code_checking_package ) {
 	    delete_package($code_checking_package);
 	}
     }
@@ -397,7 +397,7 @@ $store_initial_value_reference = sub {		# Store initial values that are
 
 $class_defined = sub {			# Return TRUE if the argument
     my $class_name = $_[0];		# is the name of a Perl package.
-    return eval 'defined %'  . $class_name . '::';
+    return eval '%'  . $class_name . '::';
 };
 					# Do the main work of processing a class.
 $process_class = sub {			# Parse its specification, generate a
@@ -481,7 +481,7 @@ $constructor_parameter_passing_style = sub {	# Establish the parameter-passing s
 	&$check_for_invalid_parameter_names(@values);
 	my @member_names = $class->public_member_names;
 	croak "$cm: Missing/extra members in style" unless $#values == $#member_names;
-	    
+
 	return Class::Generate::Positional->new(@values);
     };
     $style eq 'mix' and do {
@@ -567,7 +567,7 @@ sub get($;$) {
     my ($class_name, $default_type) = @_;
     return $classes{$class_name} if exists $classes{$class_name};
 
-    return undef if ! eval 'defined %' . $class_name . '::';	# Package doesn't exist.
+    return undef if ! eval '%' . $class_name . '::';		# Package doesn't exist.
 
     my ($class, %info);
     if ( ! eval "exists \$" . $class_name . '::{_cginfo}' ) {	# Package exists but is
@@ -608,12 +608,12 @@ sub get($;$) {
 	for my $name ( @{$info{class_methods}} ) {
 	    $class->user_defined_methods($name, Class::Generate::Class_Method->new($name));
 	}
-    }   
+    }
     if ( exists $info{instance_methods} ) {
 	for my $name ( @{$info{instance_methods}} ) {
 	    $class->user_defined_methods($name, Class::Generate::Method->new($name));
 	}
-    }   
+    }
     if ( exists $info{protected} ) {	# Set access ...
 	for my $protected_member ( @{$info{protected}} ) {
 	    $class->protected($protected_member, 1);
@@ -1464,7 +1464,7 @@ sub equals {
     my ($index, $existence_test) = @_;
     my ($sr, $or) = ('$self->' . $index, '$o->' . $index);
     my $form = "    return undef if $existence_test $sr ^ $existence_test $or;\n" .
-	       "    if ( $existence_test $sr ) { return undef unless $sr"; 
+	       "    if ( $existence_test $sr ) { return undef unless $sr";
     if ( $self->base ) {
 	$form .= "->equals($or)";
     }
@@ -1695,7 +1695,7 @@ sub values_form {
     my $self = shift;
     my ($class, $element, $member_name, $exists) = @_;
     return $class->sub_form($member_name, $member_name . '_values', "    return $exists ? values \%{$element} : ();\n");
-}    
+}
 
 sub as_var {
     my $self = shift;
@@ -1846,7 +1846,7 @@ sub form {
 	$form .= q|    croak '| . $self->name_form($class) . q|Virtual class' unless $class ne '| . $class->name . qq|';\n|;
     }
     $form .= $style->init_form($class, $self)		if ! $class->can_assign_all_params &&
-							   $style->can('init_form'); 
+							   $style->can('init_form');
     $form .= $self->param_tests_form($class, $style)	if $class->check_params;
     if ( defined $class->parents ) {
 	$form .=  $style->self_from_super_form($class);
@@ -2161,7 +2161,7 @@ sub form {				# Return a form representing
 sub class_var_form {			# Return a form for declaring a class
     my $var_spec = $_[0];		# variable.  Account for an initial value.
     return "my $var_spec;" if ! ref $var_spec;
-    return map { my $value = $$var_spec{$_}; 
+    return map { my $value = $$var_spec{$_};
 		 "my $_ = " . (ref $value ? substr($_, 0, 1) . "{$value}" : $value) . ';'
 		 } keys %$var_spec;
 }
